@@ -15,6 +15,7 @@ class ItemFilter(object):
 
     def filter_objects_by_section(self, rels, section):
         """Build a queryset containing all objects in the section subtree."""
+
         subtree = section.get_descendants(include_self=True)
         kwargs_list = [{'%s__in' % rel.field.name: subtree} for rel in rels]
         q = Q(**kwargs_list[0])
@@ -26,8 +27,7 @@ class ItemFilter(object):
         """
         Perform extra actions on the filtered items.
 
-        Example: Further filtering the items in the section to meet a
-        custom need.
+        Example: Further filtering items in the section to meet a custom need.
         """
         if hasattr(items, 'select_subclasses'):
             items = items.select_subclasses()
@@ -39,9 +39,18 @@ class ItemFilter(object):
         return self.process_items(items)
 
 
-# Deprecated. This backend used to be a function that performed the same task.
-find_related_models = ItemFilter()
-
-
 class PublishedItemFilter(ItemFilter):
     manager_attr = 'published'
+
+
+# DEPRECATED: To be removed in ArmSections 2.0
+import warnings
+
+
+class DeprecatedItemFilter(ItemFilter):  # pragma: no cover
+    def __call__(self, *args, **kwargs):
+        msg = ("find_related_models() is deprecated and will be removed in " +
+               "ArmSections 2.0. Use ItemFilter.")
+        warnings.warn(msg, DeprecationWarning, stacklevel=2)
+        return super(DeprecatedItemFilter, self).__call__(*args, **kwargs)
+find_related_models = DeprecatedItemFilter
