@@ -2,8 +2,7 @@ from django.db import models
 
 
 class SectionSlugManager(models.Manager):
-    def __init__(self, section_field="primary_section", slug_field="slug",
-            *args, **kwargs):
+    def __init__(self, section_field="primary_section", slug_field="slug", *args, **kwargs):
         super(SectionSlugManager, self).__init__(*args, **kwargs)
         self.section_field = section_field
         self.slug_field = slug_field
@@ -21,8 +20,8 @@ class SectionSlugManager(models.Manager):
             raise self.model.DoesNotExist
 
         kwargs = {
-                "%s__full_slug" % self.section_field: section_slug,
-                self.slug_field: content_slug,
+            "%s__full_slug" % self.section_field: section_slug,
+            self.slug_field: content_slug,
         }
         qs = self.model.objects.filter(**kwargs)
         if hasattr(qs, "select_subclasses"):
