@@ -1,23 +1,41 @@
-from django.conf import settings
-from django.core.exceptions import ImproperlyConfigured
+import warnings
+import django
 from django.db import models
+from django.core.exceptions import ImproperlyConfigured
 from mptt.models import MPTTModel
+from mptt.managers import TreeManager
 from mptt.fields import TreeForeignKey
 from armstrong.utils.backends import GenericBackend
 
 from .utils import get_section_many_to_many_relations
 
+
 __BACKEND_MODULE = "armstrong.core.arm_sections.backends.%s"
-SECTION_ITEM_BACKEND = (GenericBackend('ARMSTRONG_SECTION_ITEM_BACKEND',
-        defaults=__BACKEND_MODULE % "ItemFilter")
-    .get_backend())
-SECTION_PUBLISHED_BACKEND = (GenericBackend(
-        'ARMSTRONG_SECTION_PUBLISHED_BACKEND',
-        defaults=__BACKEND_MODULE % "PublishedItemFilter")
-    .get_backend())
+SECTION_ITEM_BACKEND = GenericBackend(
+    'ARMSTRONG_SECTION_ITEM_BACKEND',
+    defaults=__BACKEND_MODULE % "ItemFilter").get_backend()
+SECTION_PUBLISHED_BACKEND = GenericBackend(
+    'ARMSTRONG_SECTION_PUBLISHED_BACKEND',
+    defaults=__BACKEND_MODULE % "PublishedItemFilter").get_backend()
 
 
 class SectionManager(models.Manager):
+    def get_queryset(self):  # DROP_WITH_DJANGO15
+        """Use the same ordering as TreeManager"""
+
+        args = (self.model._mptt_meta.tree_id_attr,
+                self.model._mptt_meta.left_attr)
+        method = 'get_query_set' if django.VERSION < (1, 6) else 'get_queryset'
+        return getattr(super(SectionManager, self), method)().order_by(*args)
+
+    # DEPRECATED: To be removed in ArmSections 2.0 for Django 1.6+
+    def get_query_set(self):  # pragma: no cover
+        if django.VERSION >= (1, 6):
+            msg = ("get_query_set() is deprecated and will be removed in "
+                   "ArmSections 2.0. Use get_queryset()")
+            warnings.warn(msg, DeprecationWarning, stacklevel=2)
+        return self.get_queryset()
+
     def get(self, **kwargs):
         defaults = {}
         defaults.update(kwargs)
@@ -27,27 +45,40 @@ class SectionManager(models.Manager):
         return super(SectionManager, self).get(**defaults)
 
     def add_item(self, item, field_name=None, **kwargs):
-        section = self.get_query_set().get(**kwargs)
+        section = self.get_queryset().get(**kwargs)
         section.add_item(item, field_name=field_name)
 
     def remove_item(self, item, field_name=None, **kwargs):
-        section = self.get_query_set().get(**kwargs)
+        section = self.get_queryset().get(**kwargs)
         section.remove_item(item, field_name=field_name)
 
     def toggle_item(self, item, test_func, field_name=None, **kwargs):
-        section = self.get_query_set().get(**kwargs)
+        section = self.get_queryset().get(**kwargs)
         return section.toggle_item(item, test_func, field_name=field_name)
 
 
-class Section(MPTTModel):
+class BaseSection(MPTTModel):
+    """
+    Abstract base MPTTModel providing all Section behavior
+
+    This requires all concrete models to define a `parent` field or,
+    if you want to rename it, a field cooresponding to the `parent_attr`
+    MPTTMeta option. MPTT models require this field to build the tree.
+
+    """
     title = models.CharField(max_length=255)
     summary = models.TextField(default="", blank=True)
-    slug = models.SlugField()
-    full_slug = models.CharField(max_length=255, blank=True)
-
-    parent = TreeForeignKey('self', null=True, blank=True)
+    slug = models.SlugField(max_length=200)
+    full_slug = models.CharField(max_length=255, blank=True, unique=True)
 
     objects = SectionManager()
+    tree = TreeManager()
+
+    class Meta:
+        abstract = True
+
+    class MPTTMeta:
+        order_insertion_by = ['title']
 
     @property
     def items(self):
@@ -79,7 +110,7 @@ class Section(MPTTModel):
             self.full_slug = "%s%s/" % (self.parent.full_slug, self.slug)
         else:
             self.full_slug = "%s/" % self.slug
-        obj = super(Section, self).save(*args, **kwargs)
+        obj = super(BaseSection, self).save(*args, **kwargs)
         if orig_full_slug != self.full_slug:
             for child in self.get_children():
                 child.save()
@@ -136,3 +167,7 @@ class Section(MPTTModel):
         else:
             self.remove_item(item, field_name)
             return False
+
+
+class Section(BaseSection):
+    parent = TreeForeignKey('self', null=True, blank=True)
